declare global {
    interface Window {
        JikeOpenHybrid: {
            nativeDispatch?: any;
            webDispatch?: any;
            callbacks?: {
                [key: string]: Function;
            };
        };
    }
    const SDK_VERSION: string;
}
import 'reflect-metadata';
import { JikeOpenJsSDKConfiguration, UserInfo } from './interfaces';
/**
 * jike open platform javascript sdk.
 *
 * @export
 * @class JikeOpenJsSDK
 */
export declare class JikeOpenJsSDK {
    private _configuration;
    configuration: JikeOpenJsSDKConfiguration;
    constructor(value: string | JikeOpenJsSDKConfiguration);
    /**
     * Check whether JikeOpenHybrid Object is loaded.
     *
     * @todo Reject condition?
     * @param {Function} [cb] Callback function.
     * @memberof JikeOpenJsSDK
     */
    ready(): Promise<{}>;
    /**
     * Get user info.
     * @deprecated
     * @returns User info (just for open platform part).
     * @memberof JikeOpenJsSDK
     */
    getUserInfo_deprecated(): Promise<UserInfo>;
    /**
     * Get user info.
     *
     * @returns
     * @memberof JikeOpenJsSDK
     */
    getUserInfo(): Promise<UserInfo>;
    getMessages(topicId: string): Promise<{
        message: any[];
        count: number;
    }>;
    /**
     *
     * @private
     * @template T
     * @param {APISchema} apiSchema
     * @param {ActionCallback} [callback]
     * @returns
     * @memberof JikeOpenJsSDK
     */
    private callAPI;
    /**
     * Check whether runtime is in Jike App.
     *
     * @returns {boolean}
     * @memberof JikeOpenJsSDK
     */
    isInJikeApp(): boolean;
    /**
     * Get Jike App version.
     *
     * @returns {string} App version
     * @memberof JikeOpenJsSDK
     */
    appVersion(): string;
    /**
     * Compare input target version with current runtime version.
     *
     * @param {string} version Target version
     * @returns {number} 0: equal, 1:  higher, -1: lower
     * @memberof JikeOpenJsSDK
     */
    compareVersion(version: string): number;
    /**
     * Check whether input function can be use in runtime version.
     *
     * @todo whether needisInJikeApp
     * @param {string} funcName Function name.
     * @returns {boolean}
     * @memberof JikeOpenJsSDK
     */
    checkAvailable(funcName: string): boolean;
    /**
     * Call native method
     *
     * @private
     * @template T
     * @template R
     * @param {string} type
     * @param {T} [payload]
     * @param {ActionCallback} [callback]
     * @param {ActionMetadata} [meta]
     * @returns
     * @memberof JikeOpenJsSDK
     */
    private callNative;
    /**
     * Call native method without result
     *
     * @private
     * @template T
     * @param {string} type
     * @param {T} [payload]
     * @param {ActionCallback} [callback]
     * @param {ActionMetadata} [meta]
     * @memberof JikeOpenJsSDK
     */
    private callNativeWithoutResult;
}
